Quickstart
==========

For a ``Pasee`` to run easily you should start by running a local
`Kisee <https://github.com/meltygroup/kisee>`__.

Once a local ``Kisee`` is started follow those steps:

Install pasee in a venv::

  pip install pasee

And start it using::

  pasee --settings-file example-settings.toml
